#!/bin/bash

USAGE="Usage:
./unreal.sh [OPTION]... inputfile
Options:
 -s --semantics    Semantics among {adm,com,prf,mod}
                   Default: prf
 -f --formalism    Formalism among {af,setaf,badf,adf}
                   Default: adf
 -t --translate    Way of translation among {diamond,aspartix,none}
                   diamond (default): Output diamond-instances
                   aspartix: Output aspartix-instances
                             (only compatible with formalism af)
                   none: Output just the characterizations"

SEMANTICS="prf"
FORMALISM="adf"
#MODE="propagate"
TRANSLATE="diamond"

while [[ $# > 1 ]]
do
key="$1"

case $key in
    -s|--semantics)
    SEMANTICS="$2"
    shift # past argument
    ;;
    -f|--formalism)
    FORMALISM="$2"
    shift # past argument
    ;;
#    -m|--mode)
#    MODE="$2"
#    shift # past argument
#    ;;
    -t|--translate)
    TRANSLATE="$2"
    shift
    ;;
    *)
    echo Unknown option "$1"
    echo
    echo "${USAGE}"
    exit 1
    ;;
esac
shift # past argument or value
done


case $FORMALISM in
    af|adf|badf|setaf)
    ;;
    *)
    echo "${FORMALISM}" is not a valid formalism.
    echo
    echo "${USAGE}"
    exit 1
    ;;
esac

case $SEMANTICS in
    adm|prf|com|mod)
    ;;
    *)
    echo "${SEMANTICS}" is not a valid semantics.
    echo
    echo "${USAGE}"
    exit 1
    ;;
esac

case $TRANSLATE in
    diamond|aspartix|none)
    ;;
    *)
    echo "${TRANSLATION}" is not a valid option for translation.
    echo
    echo "${USAGE}"
    exit 1
    ;;
esac

if [[ $# < 1 ]]; then
    echo "Please specify an inputfile"
    echo
    echo "${USAGE}"
    exit 1
fi

if [[ $TRANSLATE = "aspartix" ]] && [[ $FORMALISM != "af" ]]; then
    echo "Translation to aspartix only possible for AFs."
    echo
    echo "${USAGE}"
    exit 1
fi

COMMAND="clingo -n 0 main.lp ${SEMANTICS}.lp"
if [[ $FORMALISM != "adf" ]]; then
    COMMAND="${COMMAND} ${FORMALISM}.lp"
fi
case $TRANSLATE in
    aspartix)
	COMMAND="${COMMAND} 2aspartix.lp"
	;;
    diamond)
        COMMAND="${COMMAND} 2diamond.lp"
	;;
    none)
	COMMAND="${COMMAND} show.lp"
	;;
esac

COMMAND="${COMMAND} $1"

echo Executing: "${COMMAND}"
eval $COMMAND
